@@ -1,4 +1,3 @@
-/* $Xorg: globals.c,v 1.4 2001/02/09 02:03:50 xorgcvs Exp $ */
 /*
 
 Copyright 1989, 1998  The Open Group
@@ -26,7 +25,6 @@ other dealings in this Software without prior written authorization
 from The Open Group.
 
 */
-/* $XFree86: xc/lib/Xext/globals.c,v 3.4 2001/07/29 05:01:12 tsi Exp $ */
 
 /*
  * This file should contain only those objects which must be predefined.
@@ -45,7 +43,7 @@ from The Open Group.
  */
 #ifdef NULL_NOT_ZERO			/* then need to initialize */
 #define SetZero(t,var,z) t var = z
-#else 
+#else
 #define SetZero(t,var,z) t var
 #endif
 
@@ -75,8 +73,7 @@ from The Open Group.
 /*
  * Error handlers; used to be in XlibInt.c
  */
-typedef int (*funcptr)(Display*, char *, char *);
-ZEROINIT (funcptr, _XExtensionErrorFunction, NULL);
+ZEROINIT (XextErrorHandler, _XExtensionErrorFunction, NULL);
 
 /*
  * NOTE: any additional external definition NEED
